# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetAccountDetailsReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'admin_user_policy_id': 'str',
        'customer_address': 'str',
        'customer_email': 'str',
        'customer_id': 'str',
        'customer_name': 'str',
        'customer_phone': 'str',
        'num_of_dynamic_secrets': 'int',
        'num_of_items': 'int',
        'num_of_keys': 'int',
        'num_of_roles': 'int',
        'num_of_secrets': 'int',
        'num_of_users': 'int'
    }

    attribute_map = {
        'account_id': 'account_id',
        'admin_user_policy_id': 'admin_user_policy_id',
        'customer_address': 'customer_address',
        'customer_email': 'customer_email',
        'customer_id': 'customer_id',
        'customer_name': 'customer_name',
        'customer_phone': 'customer_phone',
        'num_of_dynamic_secrets': 'num_of_dynamic_secrets',
        'num_of_items': 'num_of_items',
        'num_of_keys': 'num_of_keys',
        'num_of_roles': 'num_of_roles',
        'num_of_secrets': 'num_of_secrets',
        'num_of_users': 'num_of_users'
    }

    def __init__(self, account_id=None, admin_user_policy_id=None, customer_address=None, customer_email=None, customer_id=None, customer_name=None, customer_phone=None, num_of_dynamic_secrets=None, num_of_items=None, num_of_keys=None, num_of_roles=None, num_of_secrets=None, num_of_users=None):  # noqa: E501
        """GetAccountDetailsReplyObj - a model defined in Swagger"""  # noqa: E501

        self._account_id = None
        self._admin_user_policy_id = None
        self._customer_address = None
        self._customer_email = None
        self._customer_id = None
        self._customer_name = None
        self._customer_phone = None
        self._num_of_dynamic_secrets = None
        self._num_of_items = None
        self._num_of_keys = None
        self._num_of_roles = None
        self._num_of_secrets = None
        self._num_of_users = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if admin_user_policy_id is not None:
            self.admin_user_policy_id = admin_user_policy_id
        if customer_address is not None:
            self.customer_address = customer_address
        if customer_email is not None:
            self.customer_email = customer_email
        if customer_id is not None:
            self.customer_id = customer_id
        if customer_name is not None:
            self.customer_name = customer_name
        if customer_phone is not None:
            self.customer_phone = customer_phone
        if num_of_dynamic_secrets is not None:
            self.num_of_dynamic_secrets = num_of_dynamic_secrets
        if num_of_items is not None:
            self.num_of_items = num_of_items
        if num_of_keys is not None:
            self.num_of_keys = num_of_keys
        if num_of_roles is not None:
            self.num_of_roles = num_of_roles
        if num_of_secrets is not None:
            self.num_of_secrets = num_of_secrets
        if num_of_users is not None:
            self.num_of_users = num_of_users

    @property
    def account_id(self):
        """Gets the account_id of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The account_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this GetAccountDetailsReplyObj.


        :param account_id: The account_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def admin_user_policy_id(self):
        """Gets the admin_user_policy_id of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The admin_user_policy_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._admin_user_policy_id

    @admin_user_policy_id.setter
    def admin_user_policy_id(self, admin_user_policy_id):
        """Sets the admin_user_policy_id of this GetAccountDetailsReplyObj.


        :param admin_user_policy_id: The admin_user_policy_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._admin_user_policy_id = admin_user_policy_id

    @property
    def customer_address(self):
        """Gets the customer_address of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The customer_address of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_address

    @customer_address.setter
    def customer_address(self, customer_address):
        """Sets the customer_address of this GetAccountDetailsReplyObj.


        :param customer_address: The customer_address of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_address = customer_address

    @property
    def customer_email(self):
        """Gets the customer_email of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The customer_email of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_email

    @customer_email.setter
    def customer_email(self, customer_email):
        """Sets the customer_email of this GetAccountDetailsReplyObj.


        :param customer_email: The customer_email of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_email = customer_email

    @property
    def customer_id(self):
        """Gets the customer_id of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The customer_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id):
        """Sets the customer_id of this GetAccountDetailsReplyObj.


        :param customer_id: The customer_id of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_id = customer_id

    @property
    def customer_name(self):
        """Gets the customer_name of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The customer_name of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this GetAccountDetailsReplyObj.


        :param customer_name: The customer_name of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def customer_phone(self):
        """Gets the customer_phone of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The customer_phone of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_phone

    @customer_phone.setter
    def customer_phone(self, customer_phone):
        """Sets the customer_phone of this GetAccountDetailsReplyObj.


        :param customer_phone: The customer_phone of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_phone = customer_phone

    @property
    def num_of_dynamic_secrets(self):
        """Gets the num_of_dynamic_secrets of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_dynamic_secrets of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_dynamic_secrets

    @num_of_dynamic_secrets.setter
    def num_of_dynamic_secrets(self, num_of_dynamic_secrets):
        """Sets the num_of_dynamic_secrets of this GetAccountDetailsReplyObj.


        :param num_of_dynamic_secrets: The num_of_dynamic_secrets of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_dynamic_secrets = num_of_dynamic_secrets

    @property
    def num_of_items(self):
        """Gets the num_of_items of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_items of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_items

    @num_of_items.setter
    def num_of_items(self, num_of_items):
        """Sets the num_of_items of this GetAccountDetailsReplyObj.


        :param num_of_items: The num_of_items of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_items = num_of_items

    @property
    def num_of_keys(self):
        """Gets the num_of_keys of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_keys of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_keys

    @num_of_keys.setter
    def num_of_keys(self, num_of_keys):
        """Sets the num_of_keys of this GetAccountDetailsReplyObj.


        :param num_of_keys: The num_of_keys of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_keys = num_of_keys

    @property
    def num_of_roles(self):
        """Gets the num_of_roles of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_roles of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_roles

    @num_of_roles.setter
    def num_of_roles(self, num_of_roles):
        """Sets the num_of_roles of this GetAccountDetailsReplyObj.


        :param num_of_roles: The num_of_roles of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_roles = num_of_roles

    @property
    def num_of_secrets(self):
        """Gets the num_of_secrets of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_secrets of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_secrets

    @num_of_secrets.setter
    def num_of_secrets(self, num_of_secrets):
        """Sets the num_of_secrets of this GetAccountDetailsReplyObj.


        :param num_of_secrets: The num_of_secrets of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_secrets = num_of_secrets

    @property
    def num_of_users(self):
        """Gets the num_of_users of this GetAccountDetailsReplyObj.  # noqa: E501


        :return: The num_of_users of this GetAccountDetailsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._num_of_users

    @num_of_users.setter
    def num_of_users(self, num_of_users):
        """Sets the num_of_users of this GetAccountDetailsReplyObj.


        :param num_of_users: The num_of_users of this GetAccountDetailsReplyObj.  # noqa: E501
        :type: int
        """

        self._num_of_users = num_of_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccountDetailsReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.policy_rules import PolicyRules  # noqa: F401,E501
from akeyless_uam_api.models.policy_rules_type import PolicyRulesType  # noqa: F401,E501


class PolicyParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'attaches': 'str',
        'comment': 'str',
        'expires': 'int',
        'policy_rules_type': 'PolicyRulesType',
        'rules': 'PolicyRules'
    }

    attribute_map = {
        'account_id': 'account_id',
        'attaches': 'attaches',
        'comment': 'comment',
        'expires': 'expires',
        'policy_rules_type': 'policy_rules_type',
        'rules': 'rules'
    }

    def __init__(self, account_id=None, attaches=None, comment=None, expires=None, policy_rules_type=None, rules=None):  # noqa: E501
        """PolicyParams - a model defined in Swagger"""  # noqa: E501

        self._account_id = None
        self._attaches = None
        self._comment = None
        self._expires = None
        self._policy_rules_type = None
        self._rules = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if attaches is not None:
            self.attaches = attaches
        if comment is not None:
            self.comment = comment
        self.expires = expires
        if policy_rules_type is not None:
            self.policy_rules_type = policy_rules_type
        if rules is not None:
            self.rules = rules

    @property
    def account_id(self):
        """Gets the account_id of this PolicyParams.  # noqa: E501

        Account id.  # noqa: E501

        :return: The account_id of this PolicyParams.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PolicyParams.

        Account id.  # noqa: E501

        :param account_id: The account_id of this PolicyParams.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def attaches(self):
        """Gets the attaches of this PolicyParams.  # noqa: E501

        Generic field in a JSON format that contains additional information about the policy. This JSON will be attached to the temporary credentials that will be issued for this policy.  # noqa: E501

        :return: The attaches of this PolicyParams.  # noqa: E501
        :rtype: str
        """
        return self._attaches

    @attaches.setter
    def attaches(self, attaches):
        """Sets the attaches of this PolicyParams.

        Generic field in a JSON format that contains additional information about the policy. This JSON will be attached to the temporary credentials that will be issued for this policy.  # noqa: E501

        :param attaches: The attaches of this PolicyParams.  # noqa: E501
        :type: str
        """

        self._attaches = attaches

    @property
    def comment(self):
        """Gets the comment of this PolicyParams.  # noqa: E501

        Comments  # noqa: E501

        :return: The comment of this PolicyParams.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this PolicyParams.

        Comments  # noqa: E501

        :param comment: The comment of this PolicyParams.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def expires(self):
        """Gets the expires of this PolicyParams.  # noqa: E501

        Policy expiration date (Unix timestamp).  # noqa: E501

        :return: The expires of this PolicyParams.  # noqa: E501
        :rtype: int
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """Sets the expires of this PolicyParams.

        Policy expiration date (Unix timestamp).  # noqa: E501

        :param expires: The expires of this PolicyParams.  # noqa: E501
        :type: int
        """
        if expires is None:
            raise ValueError("Invalid value for `expires`, must not be `None`")  # noqa: E501

        self._expires = expires

    @property
    def policy_rules_type(self):
        """Gets the policy_rules_type of this PolicyParams.  # noqa: E501


        :return: The policy_rules_type of this PolicyParams.  # noqa: E501
        :rtype: PolicyRulesType
        """
        return self._policy_rules_type

    @policy_rules_type.setter
    def policy_rules_type(self, policy_rules_type):
        """Sets the policy_rules_type of this PolicyParams.


        :param policy_rules_type: The policy_rules_type of this PolicyParams.  # noqa: E501
        :type: PolicyRulesType
        """

        self._policy_rules_type = policy_rules_type

    @property
    def rules(self):
        """Gets the rules of this PolicyParams.  # noqa: E501


        :return: The rules of this PolicyParams.  # noqa: E501
        :rtype: PolicyRules
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this PolicyParams.


        :param rules: The rules of this PolicyParams.  # noqa: E501
        :type: PolicyRules
        """

        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.algorithm import Algorithm  # noqa: F401,E501
from akeyless_uam_api.models.azure_ad_access_role import AzureADAccessRole  # noqa: F401,E501
from akeyless_uam_api.models.o_auth2_access_role import OAuth2AccessRole  # noqa: F401,E501


class PolicyRules(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alg': 'Algorithm',
        'azure_ad_access_role': 'AzureADAccessRole',
        'cidr_whitelist': 'str',
        'key': 'str',
        'oauth2_access_role': 'OAuth2AccessRole'
    }

    attribute_map = {
        'alg': 'alg',
        'azure_ad_access_role': 'azure_ad_access_role',
        'cidr_whitelist': 'cidr_whitelist',
        'key': 'key',
        'oauth2_access_role': 'oauth2_access_role'
    }

    def __init__(self, alg=None, azure_ad_access_role=None, cidr_whitelist=None, key=None, oauth2_access_role=None):  # noqa: E501
        """PolicyRules - a model defined in Swagger"""  # noqa: E501

        self._alg = None
        self._azure_ad_access_role = None
        self._cidr_whitelist = None
        self._key = None
        self._oauth2_access_role = None
        self.discriminator = None

        if alg is not None:
            self.alg = alg
        if azure_ad_access_role is not None:
            self.azure_ad_access_role = azure_ad_access_role
        if cidr_whitelist is not None:
            self.cidr_whitelist = cidr_whitelist
        if key is not None:
            self.key = key
        if oauth2_access_role is not None:
            self.oauth2_access_role = oauth2_access_role

    @property
    def alg(self):
        """Gets the alg of this PolicyRules.  # noqa: E501


        :return: The alg of this PolicyRules.  # noqa: E501
        :rtype: Algorithm
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """Sets the alg of this PolicyRules.


        :param alg: The alg of this PolicyRules.  # noqa: E501
        :type: Algorithm
        """

        self._alg = alg

    @property
    def azure_ad_access_role(self):
        """Gets the azure_ad_access_role of this PolicyRules.  # noqa: E501


        :return: The azure_ad_access_role of this PolicyRules.  # noqa: E501
        :rtype: AzureADAccessRole
        """
        return self._azure_ad_access_role

    @azure_ad_access_role.setter
    def azure_ad_access_role(self, azure_ad_access_role):
        """Sets the azure_ad_access_role of this PolicyRules.


        :param azure_ad_access_role: The azure_ad_access_role of this PolicyRules.  # noqa: E501
        :type: AzureADAccessRole
        """

        self._azure_ad_access_role = azure_ad_access_role

    @property
    def cidr_whitelist(self):
        """Gets the cidr_whitelist of this PolicyRules.  # noqa: E501

        CIDR Whitelisting. Only requests from the ip addresses that match the CIDR list will be able to obtain temporary access credentials. The format of the CIDR list is a comma-separated list of valid CIDRs.The list length is limited to 10 CIDRs. In the case of an empty string there will be no restriction of IP addresses.  # noqa: E501

        :return: The cidr_whitelist of this PolicyRules.  # noqa: E501
        :rtype: str
        """
        return self._cidr_whitelist

    @cidr_whitelist.setter
    def cidr_whitelist(self, cidr_whitelist):
        """Sets the cidr_whitelist of this PolicyRules.

        CIDR Whitelisting. Only requests from the ip addresses that match the CIDR list will be able to obtain temporary access credentials. The format of the CIDR list is a comma-separated list of valid CIDRs.The list length is limited to 10 CIDRs. In the case of an empty string there will be no restriction of IP addresses.  # noqa: E501

        :param cidr_whitelist: The cidr_whitelist of this PolicyRules.  # noqa: E501
        :type: str
        """

        self._cidr_whitelist = cidr_whitelist

    @property
    def key(self):
        """Gets the key of this PolicyRules.  # noqa: E501

        The public key value of the API-key. This is a mandatory parameter for API key policy.  # noqa: E501

        :return: The key of this PolicyRules.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this PolicyRules.

        The public key value of the API-key. This is a mandatory parameter for API key policy.  # noqa: E501

        :param key: The key of this PolicyRules.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def oauth2_access_role(self):
        """Gets the oauth2_access_role of this PolicyRules.  # noqa: E501


        :return: The oauth2_access_role of this PolicyRules.  # noqa: E501
        :rtype: OAuth2AccessRole
        """
        return self._oauth2_access_role

    @oauth2_access_role.setter
    def oauth2_access_role(self, oauth2_access_role):
        """Sets the oauth2_access_role of this PolicyRules.


        :param oauth2_access_role: The oauth2_access_role of this PolicyRules.  # noqa: E501
        :type: OAuth2AccessRole
        """

        self._oauth2_access_role = oauth2_access_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyRules):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.algorithm import Algorithm  # noqa: F401,E501
from akeyless_uam_api.models.azure_ad_access_role import AzureADAccessRole  # noqa: F401,E501
from akeyless_uam_api.models.o_auth2_access_role import OAuth2AccessRole  # noqa: F401,E501


class UserAccessPolicyInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_expires': 'int',
        'api_key_alg': 'Algorithm',
        'azure_ad_access_role': 'AzureADAccessRole',
        'cidr_whitelist': 'str',
        'oauth2_access_role': 'OAuth2AccessRole',
        'rules_type': 'str'
    }

    attribute_map = {
        'access_expires': 'access_expires',
        'api_key_alg': 'api_key_alg',
        'azure_ad_access_role': 'azure_ad_access_role',
        'cidr_whitelist': 'cidr_whitelist',
        'oauth2_access_role': 'oauth2_access_role',
        'rules_type': 'rules_type'
    }

    def __init__(self, access_expires=None, api_key_alg=None, azure_ad_access_role=None, cidr_whitelist=None, oauth2_access_role=None, rules_type=None):  # noqa: E501
        """UserAccessPolicyInfo - a model defined in Swagger"""  # noqa: E501

        self._access_expires = None
        self._api_key_alg = None
        self._azure_ad_access_role = None
        self._cidr_whitelist = None
        self._oauth2_access_role = None
        self._rules_type = None
        self.discriminator = None

        if access_expires is not None:
            self.access_expires = access_expires
        if api_key_alg is not None:
            self.api_key_alg = api_key_alg
        if azure_ad_access_role is not None:
            self.azure_ad_access_role = azure_ad_access_role
        if cidr_whitelist is not None:
            self.cidr_whitelist = cidr_whitelist
        if oauth2_access_role is not None:
            self.oauth2_access_role = oauth2_access_role
        if rules_type is not None:
            self.rules_type = rules_type

    @property
    def access_expires(self):
        """Gets the access_expires of this UserAccessPolicyInfo.  # noqa: E501


        :return: The access_expires of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: int
        """
        return self._access_expires

    @access_expires.setter
    def access_expires(self, access_expires):
        """Sets the access_expires of this UserAccessPolicyInfo.


        :param access_expires: The access_expires of this UserAccessPolicyInfo.  # noqa: E501
        :type: int
        """

        self._access_expires = access_expires

    @property
    def api_key_alg(self):
        """Gets the api_key_alg of this UserAccessPolicyInfo.  # noqa: E501


        :return: The api_key_alg of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: Algorithm
        """
        return self._api_key_alg

    @api_key_alg.setter
    def api_key_alg(self, api_key_alg):
        """Sets the api_key_alg of this UserAccessPolicyInfo.


        :param api_key_alg: The api_key_alg of this UserAccessPolicyInfo.  # noqa: E501
        :type: Algorithm
        """

        self._api_key_alg = api_key_alg

    @property
    def azure_ad_access_role(self):
        """Gets the azure_ad_access_role of this UserAccessPolicyInfo.  # noqa: E501


        :return: The azure_ad_access_role of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: AzureADAccessRole
        """
        return self._azure_ad_access_role

    @azure_ad_access_role.setter
    def azure_ad_access_role(self, azure_ad_access_role):
        """Sets the azure_ad_access_role of this UserAccessPolicyInfo.


        :param azure_ad_access_role: The azure_ad_access_role of this UserAccessPolicyInfo.  # noqa: E501
        :type: AzureADAccessRole
        """

        self._azure_ad_access_role = azure_ad_access_role

    @property
    def cidr_whitelist(self):
        """Gets the cidr_whitelist of this UserAccessPolicyInfo.  # noqa: E501


        :return: The cidr_whitelist of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: str
        """
        return self._cidr_whitelist

    @cidr_whitelist.setter
    def cidr_whitelist(self, cidr_whitelist):
        """Sets the cidr_whitelist of this UserAccessPolicyInfo.


        :param cidr_whitelist: The cidr_whitelist of this UserAccessPolicyInfo.  # noqa: E501
        :type: str
        """

        self._cidr_whitelist = cidr_whitelist

    @property
    def oauth2_access_role(self):
        """Gets the oauth2_access_role of this UserAccessPolicyInfo.  # noqa: E501


        :return: The oauth2_access_role of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: OAuth2AccessRole
        """
        return self._oauth2_access_role

    @oauth2_access_role.setter
    def oauth2_access_role(self, oauth2_access_role):
        """Sets the oauth2_access_role of this UserAccessPolicyInfo.


        :param oauth2_access_role: The oauth2_access_role of this UserAccessPolicyInfo.  # noqa: E501
        :type: OAuth2AccessRole
        """

        self._oauth2_access_role = oauth2_access_role

    @property
    def rules_type(self):
        """Gets the rules_type of this UserAccessPolicyInfo.  # noqa: E501


        :return: The rules_type of this UserAccessPolicyInfo.  # noqa: E501
        :rtype: str
        """
        return self._rules_type

    @rules_type.setter
    def rules_type(self, rules_type):
        """Sets the rules_type of this UserAccessPolicyInfo.


        :param rules_type: The rules_type of this UserAccessPolicyInfo.  # noqa: E501
        :type: str
        """

        self._rules_type = rules_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserAccessPolicyInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SystemUserCredentialsReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_creds': 'str',
        'expiry': 'int',
        'kfm_creds': 'str',
        'uam_creds': 'str'
    }

    attribute_map = {
        'auth_creds': 'auth_creds',
        'expiry': 'expiry',
        'kfm_creds': 'kfm_creds',
        'uam_creds': 'uam_creds'
    }

    def __init__(self, auth_creds=None, expiry=None, kfm_creds=None, uam_creds=None):  # noqa: E501
        """SystemUserCredentialsReplyObj - a model defined in Swagger"""  # noqa: E501

        self._auth_creds = None
        self._expiry = None
        self._kfm_creds = None
        self._uam_creds = None
        self.discriminator = None

        if auth_creds is not None:
            self.auth_creds = auth_creds
        if expiry is not None:
            self.expiry = expiry
        if kfm_creds is not None:
            self.kfm_creds = kfm_creds
        if uam_creds is not None:
            self.uam_creds = uam_creds

    @property
    def auth_creds(self):
        """Gets the auth_creds of this SystemUserCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing Auth  # noqa: E501

        :return: The auth_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._auth_creds

    @auth_creds.setter
    def auth_creds(self, auth_creds):
        """Sets the auth_creds of this SystemUserCredentialsReplyObj.

        Temporary credentials for accessing Auth  # noqa: E501

        :param auth_creds: The auth_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._auth_creds = auth_creds

    @property
    def expiry(self):
        """Gets the expiry of this SystemUserCredentialsReplyObj.  # noqa: E501

        Credentials expiration date  # noqa: E501

        :return: The expiry of this SystemUserCredentialsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this SystemUserCredentialsReplyObj.

        Credentials expiration date  # noqa: E501

        :param expiry: The expiry of this SystemUserCredentialsReplyObj.  # noqa: E501
        :type: int
        """

        self._expiry = expiry

    @property
    def kfm_creds(self):
        """Gets the kfm_creds of this SystemUserCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing the KFMs instances  # noqa: E501

        :return: The kfm_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._kfm_creds

    @kfm_creds.setter
    def kfm_creds(self, kfm_creds):
        """Sets the kfm_creds of this SystemUserCredentialsReplyObj.

        Temporary credentials for accessing the KFMs instances  # noqa: E501

        :param kfm_creds: The kfm_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._kfm_creds = kfm_creds

    @property
    def uam_creds(self):
        """Gets the uam_creds of this SystemUserCredentialsReplyObj.  # noqa: E501

        Temporary credentials for accessing the UAM service  # noqa: E501

        :return: The uam_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._uam_creds

    @uam_creds.setter
    def uam_creds(self, uam_creds):
        """Sets the uam_creds of this SystemUserCredentialsReplyObj.

        Temporary credentials for accessing the UAM service  # noqa: E501

        :param uam_creds: The uam_creds of this SystemUserCredentialsReplyObj.  # noqa: E501
        :type: str
        """

        self._uam_creds = uam_creds

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SystemUserCredentialsReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SecretAccessCredsReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kf_ms_hosts_dns_map': 'dict(str, str)',
        'credential': 'str',
        'customer_fragment_id': 'str',
        'expiry': 'int',
        'item_size': 'int',
        'item_type': 'str',
        'item_version': 'int',
        'restricted_dd': 'str',
        'secret_enc_val': 'str',
        'secret_id': 'int',
        'secret_name': 'str',
        'secret_type': 'str',
        'secret_version': 'int'
    }

    attribute_map = {
        'kf_ms_hosts_dns_map': 'KFMsHostsDNSMap',
        'credential': 'credential',
        'customer_fragment_id': 'customer_fragment_id',
        'expiry': 'expiry',
        'item_size': 'item_size',
        'item_type': 'item_type',
        'item_version': 'item_version',
        'restricted_dd': 'restricted_dd',
        'secret_enc_val': 'secret_enc_val',
        'secret_id': 'secret_id',
        'secret_name': 'secret_name',
        'secret_type': 'secret_type',
        'secret_version': 'secret_version'
    }

    def __init__(self, kf_ms_hosts_dns_map=None, credential=None, customer_fragment_id=None, expiry=None, item_size=None, item_type=None, item_version=None, restricted_dd=None, secret_enc_val=None, secret_id=None, secret_name=None, secret_type=None, secret_version=None):  # noqa: E501
        """SecretAccessCredsReplyObj - a model defined in Swagger"""  # noqa: E501

        self._kf_ms_hosts_dns_map = None
        self._credential = None
        self._customer_fragment_id = None
        self._expiry = None
        self._item_size = None
        self._item_type = None
        self._item_version = None
        self._restricted_dd = None
        self._secret_enc_val = None
        self._secret_id = None
        self._secret_name = None
        self._secret_type = None
        self._secret_version = None
        self.discriminator = None

        if kf_ms_hosts_dns_map is not None:
            self.kf_ms_hosts_dns_map = kf_ms_hosts_dns_map
        if credential is not None:
            self.credential = credential
        if customer_fragment_id is not None:
            self.customer_fragment_id = customer_fragment_id
        if expiry is not None:
            self.expiry = expiry
        if item_size is not None:
            self.item_size = item_size
        if item_type is not None:
            self.item_type = item_type
        if item_version is not None:
            self.item_version = item_version
        if restricted_dd is not None:
            self.restricted_dd = restricted_dd
        if secret_enc_val is not None:
            self.secret_enc_val = secret_enc_val
        if secret_id is not None:
            self.secret_id = secret_id
        if secret_name is not None:
            self.secret_name = secret_name
        if secret_type is not None:
            self.secret_type = secret_type
        if secret_version is not None:
            self.secret_version = secret_version

    @property
    def kf_ms_hosts_dns_map(self):
        """Gets the kf_ms_hosts_dns_map of this SecretAccessCredsReplyObj.  # noqa: E501

        Mapping between the serial number of the key fragments and the KFMs hosts DNS in which they are stored.  # noqa: E501

        :return: The kf_ms_hosts_dns_map of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._kf_ms_hosts_dns_map

    @kf_ms_hosts_dns_map.setter
    def kf_ms_hosts_dns_map(self, kf_ms_hosts_dns_map):
        """Sets the kf_ms_hosts_dns_map of this SecretAccessCredsReplyObj.

        Mapping between the serial number of the key fragments and the KFMs hosts DNS in which they are stored.  # noqa: E501

        :param kf_ms_hosts_dns_map: The kf_ms_hosts_dns_map of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: dict(str, str)
        """

        self._kf_ms_hosts_dns_map = kf_ms_hosts_dns_map

    @property
    def credential(self):
        """Gets the credential of this SecretAccessCredsReplyObj.  # noqa: E501

        Temporary credentials string (JWT format)  # noqa: E501

        :return: The credential of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """Sets the credential of this SecretAccessCredsReplyObj.

        Temporary credentials string (JWT format)  # noqa: E501

        :param credential: The credential of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._credential = credential

    @property
    def customer_fragment_id(self):
        """Gets the customer_fragment_id of this SecretAccessCredsReplyObj.  # noqa: E501

        The customer fragment ID associated with this key (if any).  # noqa: E501

        :return: The customer_fragment_id of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_fragment_id

    @customer_fragment_id.setter
    def customer_fragment_id(self, customer_fragment_id):
        """Sets the customer_fragment_id of this SecretAccessCredsReplyObj.

        The customer fragment ID associated with this key (if any).  # noqa: E501

        :param customer_fragment_id: The customer_fragment_id of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_fragment_id = customer_fragment_id

    @property
    def expiry(self):
        """Gets the expiry of this SecretAccessCredsReplyObj.  # noqa: E501

        Credentials expiration date  # noqa: E501

        :return: The expiry of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this SecretAccessCredsReplyObj.

        Credentials expiration date  # noqa: E501

        :param expiry: The expiry of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._expiry = expiry

    @property
    def item_size(self):
        """Gets the item_size of this SecretAccessCredsReplyObj.  # noqa: E501


        :return: The item_size of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_size

    @item_size.setter
    def item_size(self, item_size):
        """Sets the item_size of this SecretAccessCredsReplyObj.


        :param item_size: The item_size of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._item_size = item_size

    @property
    def item_type(self):
        """Gets the item_type of this SecretAccessCredsReplyObj.  # noqa: E501


        :return: The item_type of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this SecretAccessCredsReplyObj.


        :param item_type: The item_type of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def item_version(self):
        """Gets the item_version of this SecretAccessCredsReplyObj.  # noqa: E501

        The version, type and size of the key that the fragments belong to  # noqa: E501

        :return: The item_version of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this SecretAccessCredsReplyObj.

        The version, type and size of the key that the fragments belong to  # noqa: E501

        :param item_version: The item_version of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._item_version = item_version

    @property
    def restricted_dd(self):
        """Gets the restricted_dd of this SecretAccessCredsReplyObj.  # noqa: E501

        In case not empty, the derivation operation will be restricted to this derivation data  # noqa: E501

        :return: The restricted_dd of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._restricted_dd

    @restricted_dd.setter
    def restricted_dd(self, restricted_dd):
        """Sets the restricted_dd of this SecretAccessCredsReplyObj.

        In case not empty, the derivation operation will be restricted to this derivation data  # noqa: E501

        :param restricted_dd: The restricted_dd of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._restricted_dd = restricted_dd

    @property
    def secret_enc_val(self):
        """Gets the secret_enc_val of this SecretAccessCredsReplyObj.  # noqa: E501

        The encrypted secret value.  # noqa: E501

        :return: The secret_enc_val of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._secret_enc_val

    @secret_enc_val.setter
    def secret_enc_val(self, secret_enc_val):
        """Sets the secret_enc_val of this SecretAccessCredsReplyObj.

        The encrypted secret value.  # noqa: E501

        :param secret_enc_val: The secret_enc_val of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._secret_enc_val = secret_enc_val

    @property
    def secret_id(self):
        """Gets the secret_id of this SecretAccessCredsReplyObj.  # noqa: E501


        :return: The secret_id of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """Sets the secret_id of this SecretAccessCredsReplyObj.


        :param secret_id: The secret_id of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._secret_id = secret_id

    @property
    def secret_name(self):
        """Gets the secret_name of this SecretAccessCredsReplyObj.  # noqa: E501

        The name, id, version and type of the secret item  # noqa: E501

        :return: The secret_name of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._secret_name

    @secret_name.setter
    def secret_name(self, secret_name):
        """Sets the secret_name of this SecretAccessCredsReplyObj.

        The name, id, version and type of the secret item  # noqa: E501

        :param secret_name: The secret_name of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._secret_name = secret_name

    @property
    def secret_type(self):
        """Gets the secret_type of this SecretAccessCredsReplyObj.  # noqa: E501


        :return: The secret_type of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._secret_type

    @secret_type.setter
    def secret_type(self, secret_type):
        """Sets the secret_type of this SecretAccessCredsReplyObj.


        :param secret_type: The secret_type of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._secret_type = secret_type

    @property
    def secret_version(self):
        """Gets the secret_version of this SecretAccessCredsReplyObj.  # noqa: E501


        :return: The secret_version of this SecretAccessCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._secret_version

    @secret_version.setter
    def secret_version(self, secret_version):
        """Sets the secret_version of this SecretAccessCredsReplyObj.


        :param secret_version: The secret_version of this SecretAccessCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._secret_version = secret_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecretAccessCredsReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DerivationCredsReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kf_ms_hosts_dns_map': 'dict(str, str)',
        'credential': 'str',
        'customer_fragment_id': 'str',
        'expiry': 'int',
        'item_id': 'int',
        'item_name': 'str',
        'item_size': 'int',
        'item_type': 'str',
        'item_version': 'int',
        'restricted_dd': 'str'
    }

    attribute_map = {
        'kf_ms_hosts_dns_map': 'KFMsHostsDNSMap',
        'credential': 'credential',
        'customer_fragment_id': 'customer_fragment_id',
        'expiry': 'expiry',
        'item_id': 'item_id',
        'item_name': 'item_name',
        'item_size': 'item_size',
        'item_type': 'item_type',
        'item_version': 'item_version',
        'restricted_dd': 'restricted_dd'
    }

    def __init__(self, kf_ms_hosts_dns_map=None, credential=None, customer_fragment_id=None, expiry=None, item_id=None, item_name=None, item_size=None, item_type=None, item_version=None, restricted_dd=None):  # noqa: E501
        """DerivationCredsReplyObj - a model defined in Swagger"""  # noqa: E501

        self._kf_ms_hosts_dns_map = None
        self._credential = None
        self._customer_fragment_id = None
        self._expiry = None
        self._item_id = None
        self._item_name = None
        self._item_size = None
        self._item_type = None
        self._item_version = None
        self._restricted_dd = None
        self.discriminator = None

        if kf_ms_hosts_dns_map is not None:
            self.kf_ms_hosts_dns_map = kf_ms_hosts_dns_map
        if credential is not None:
            self.credential = credential
        if customer_fragment_id is not None:
            self.customer_fragment_id = customer_fragment_id
        if expiry is not None:
            self.expiry = expiry
        if item_id is not None:
            self.item_id = item_id
        if item_name is not None:
            self.item_name = item_name
        if item_size is not None:
            self.item_size = item_size
        if item_type is not None:
            self.item_type = item_type
        if item_version is not None:
            self.item_version = item_version
        if restricted_dd is not None:
            self.restricted_dd = restricted_dd

    @property
    def kf_ms_hosts_dns_map(self):
        """Gets the kf_ms_hosts_dns_map of this DerivationCredsReplyObj.  # noqa: E501

        Mapping between the serial number of the key fragments and the KFMs hosts DNS in which they are stored.  # noqa: E501

        :return: The kf_ms_hosts_dns_map of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._kf_ms_hosts_dns_map

    @kf_ms_hosts_dns_map.setter
    def kf_ms_hosts_dns_map(self, kf_ms_hosts_dns_map):
        """Sets the kf_ms_hosts_dns_map of this DerivationCredsReplyObj.

        Mapping between the serial number of the key fragments and the KFMs hosts DNS in which they are stored.  # noqa: E501

        :param kf_ms_hosts_dns_map: The kf_ms_hosts_dns_map of this DerivationCredsReplyObj.  # noqa: E501
        :type: dict(str, str)
        """

        self._kf_ms_hosts_dns_map = kf_ms_hosts_dns_map

    @property
    def credential(self):
        """Gets the credential of this DerivationCredsReplyObj.  # noqa: E501

        Temporary credentials string (JWT format)  # noqa: E501

        :return: The credential of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """Sets the credential of this DerivationCredsReplyObj.

        Temporary credentials string (JWT format)  # noqa: E501

        :param credential: The credential of this DerivationCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._credential = credential

    @property
    def customer_fragment_id(self):
        """Gets the customer_fragment_id of this DerivationCredsReplyObj.  # noqa: E501

        The customer fragment ID associated with this key (if any).  # noqa: E501

        :return: The customer_fragment_id of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._customer_fragment_id

    @customer_fragment_id.setter
    def customer_fragment_id(self, customer_fragment_id):
        """Sets the customer_fragment_id of this DerivationCredsReplyObj.

        The customer fragment ID associated with this key (if any).  # noqa: E501

        :param customer_fragment_id: The customer_fragment_id of this DerivationCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._customer_fragment_id = customer_fragment_id

    @property
    def expiry(self):
        """Gets the expiry of this DerivationCredsReplyObj.  # noqa: E501

        Credentials expiration date  # noqa: E501

        :return: The expiry of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this DerivationCredsReplyObj.

        Credentials expiration date  # noqa: E501

        :param expiry: The expiry of this DerivationCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._expiry = expiry

    @property
    def item_id(self):
        """Gets the item_id of this DerivationCredsReplyObj.  # noqa: E501


        :return: The item_id of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this DerivationCredsReplyObj.


        :param item_id: The item_id of this DerivationCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def item_name(self):
        """Gets the item_name of this DerivationCredsReplyObj.  # noqa: E501

        The name and id of the item that the fragments belong to  # noqa: E501

        :return: The item_name of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this DerivationCredsReplyObj.

        The name and id of the item that the fragments belong to  # noqa: E501

        :param item_name: The item_name of this DerivationCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def item_size(self):
        """Gets the item_size of this DerivationCredsReplyObj.  # noqa: E501


        :return: The item_size of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_size

    @item_size.setter
    def item_size(self, item_size):
        """Sets the item_size of this DerivationCredsReplyObj.


        :param item_size: The item_size of this DerivationCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._item_size = item_size

    @property
    def item_type(self):
        """Gets the item_type of this DerivationCredsReplyObj.  # noqa: E501


        :return: The item_type of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this DerivationCredsReplyObj.


        :param item_type: The item_type of this DerivationCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def item_version(self):
        """Gets the item_version of this DerivationCredsReplyObj.  # noqa: E501

        The version, type and size of the key that the fragments belong to  # noqa: E501

        :return: The item_version of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this DerivationCredsReplyObj.

        The version, type and size of the key that the fragments belong to  # noqa: E501

        :param item_version: The item_version of this DerivationCredsReplyObj.  # noqa: E501
        :type: int
        """

        self._item_version = item_version

    @property
    def restricted_dd(self):
        """Gets the restricted_dd of this DerivationCredsReplyObj.  # noqa: E501

        In case not empty, the derivation operation will be restricted to this derivation data  # noqa: E501

        :return: The restricted_dd of this DerivationCredsReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._restricted_dd

    @restricted_dd.setter
    def restricted_dd(self, restricted_dd):
        """Sets the restricted_dd of this DerivationCredsReplyObj.

        In case not empty, the derivation operation will be restricted to this derivation data  # noqa: E501

        :param restricted_dd: The restricted_dd of this DerivationCredsReplyObj.  # noqa: E501
        :type: str
        """

        self._restricted_dd = restricted_dd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DerivationCredsReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DynamicSecretMessageQueueInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mq_type': 'str',
        'queue_url': 'str'
    }

    attribute_map = {
        'mq_type': 'mq_type',
        'queue_url': 'queue_url'
    }

    def __init__(self, mq_type=None, queue_url=None):  # noqa: E501
        """DynamicSecretMessageQueueInfo - a model defined in Swagger"""  # noqa: E501

        self._mq_type = None
        self._queue_url = None
        self.discriminator = None

        if mq_type is not None:
            self.mq_type = mq_type
        if queue_url is not None:
            self.queue_url = queue_url

    @property
    def mq_type(self):
        """Gets the mq_type of this DynamicSecretMessageQueueInfo.  # noqa: E501


        :return: The mq_type of this DynamicSecretMessageQueueInfo.  # noqa: E501
        :rtype: str
        """
        return self._mq_type

    @mq_type.setter
    def mq_type(self, mq_type):
        """Sets the mq_type of this DynamicSecretMessageQueueInfo.


        :param mq_type: The mq_type of this DynamicSecretMessageQueueInfo.  # noqa: E501
        :type: str
        """

        self._mq_type = mq_type

    @property
    def queue_url(self):
        """Gets the queue_url of this DynamicSecretMessageQueueInfo.  # noqa: E501


        :return: The queue_url of this DynamicSecretMessageQueueInfo.  # noqa: E501
        :rtype: str
        """
        return self._queue_url

    @queue_url.setter
    def queue_url(self, queue_url):
        """Sets the queue_url of this DynamicSecretMessageQueueInfo.


        :param queue_url: The queue_url of this DynamicSecretMessageQueueInfo.  # noqa: E501
        :type: str
        """

        self._queue_url = queue_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DynamicSecretMessageQueueInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.policy_rules import PolicyRules  # noqa: F401,E501
from akeyless_uam_api.models.policy_rules_type import PolicyRulesType  # noqa: F401,E501


class CreateAccountCredsParams(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_admin_user_email': 'str',
        'account_admin_user_phone': 'str',
        'expires': 'int',
        'policy_rules_type': 'PolicyRulesType',
        'rules': 'PolicyRules'
    }

    attribute_map = {
        'account_admin_user_email': 'account_admin_user_email',
        'account_admin_user_phone': 'account_admin_user_phone',
        'expires': 'expires',
        'policy_rules_type': 'policy_rules_type',
        'rules': 'rules'
    }

    def __init__(self, account_admin_user_email=None, account_admin_user_phone=None, expires=None, policy_rules_type=None, rules=None):  # noqa: E501
        """CreateAccountCredsParams - a model defined in Swagger"""  # noqa: E501

        self._account_admin_user_email = None
        self._account_admin_user_phone = None
        self._expires = None
        self._policy_rules_type = None
        self._rules = None
        self.discriminator = None

        if account_admin_user_email is not None:
            self.account_admin_user_email = account_admin_user_email
        if account_admin_user_phone is not None:
            self.account_admin_user_phone = account_admin_user_phone
        if expires is not None:
            self.expires = expires
        if policy_rules_type is not None:
            self.policy_rules_type = policy_rules_type
        if rules is not None:
            self.rules = rules

    @property
    def account_admin_user_email(self):
        """Gets the account_admin_user_email of this CreateAccountCredsParams.  # noqa: E501

        Account admin user email  # noqa: E501

        :return: The account_admin_user_email of this CreateAccountCredsParams.  # noqa: E501
        :rtype: str
        """
        return self._account_admin_user_email

    @account_admin_user_email.setter
    def account_admin_user_email(self, account_admin_user_email):
        """Sets the account_admin_user_email of this CreateAccountCredsParams.

        Account admin user email  # noqa: E501

        :param account_admin_user_email: The account_admin_user_email of this CreateAccountCredsParams.  # noqa: E501
        :type: str
        """

        self._account_admin_user_email = account_admin_user_email

    @property
    def account_admin_user_phone(self):
        """Gets the account_admin_user_phone of this CreateAccountCredsParams.  # noqa: E501

        Account admin user phone  # noqa: E501

        :return: The account_admin_user_phone of this CreateAccountCredsParams.  # noqa: E501
        :rtype: str
        """
        return self._account_admin_user_phone

    @account_admin_user_phone.setter
    def account_admin_user_phone(self, account_admin_user_phone):
        """Sets the account_admin_user_phone of this CreateAccountCredsParams.

        Account admin user phone  # noqa: E501

        :param account_admin_user_phone: The account_admin_user_phone of this CreateAccountCredsParams.  # noqa: E501
        :type: str
        """

        self._account_admin_user_phone = account_admin_user_phone

    @property
    def expires(self):
        """Gets the expires of this CreateAccountCredsParams.  # noqa: E501

        Policy expiration date (Unix timestamp).  # noqa: E501

        :return: The expires of this CreateAccountCredsParams.  # noqa: E501
        :rtype: int
        """
        return self._expires

    @expires.setter
    def expires(self, expires):
        """Sets the expires of this CreateAccountCredsParams.

        Policy expiration date (Unix timestamp).  # noqa: E501

        :param expires: The expires of this CreateAccountCredsParams.  # noqa: E501
        :type: int
        """

        self._expires = expires

    @property
    def policy_rules_type(self):
        """Gets the policy_rules_type of this CreateAccountCredsParams.  # noqa: E501


        :return: The policy_rules_type of this CreateAccountCredsParams.  # noqa: E501
        :rtype: PolicyRulesType
        """
        return self._policy_rules_type

    @policy_rules_type.setter
    def policy_rules_type(self, policy_rules_type):
        """Sets the policy_rules_type of this CreateAccountCredsParams.


        :param policy_rules_type: The policy_rules_type of this CreateAccountCredsParams.  # noqa: E501
        :type: PolicyRulesType
        """

        self._policy_rules_type = policy_rules_type

    @property
    def rules(self):
        """Gets the rules of this CreateAccountCredsParams.  # noqa: E501


        :return: The rules of this CreateAccountCredsParams.  # noqa: E501
        :rtype: PolicyRules
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this CreateAccountCredsParams.


        :param rules: The rules of this CreateAccountCredsParams.  # noqa: E501
        :type: PolicyRules
        """

        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAccountCredsParams):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import akeyless_uam_api
from akeyless_uam_api.models.create_account_creds_params import CreateAccountCredsParams  # noqa: E501
from akeyless_uam_api.rest import ApiException


class TestCreateAccountCredsParams(unittest.TestCase):
    """CreateAccountCredsParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateAccountCredsParams(self):
        """Test CreateAccountCredsParams"""
        # FIXME: construct object with mandatory attributes with example values
        # model = akeyless_uam_api.models.create_account_creds_params.CreateAccountCredsParams()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetRoleReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'role_action': 'str',
        'role_items': 'list[str]',
        'role_name': 'str',
        'role_users': 'list[str]'
    }

    attribute_map = {
        'comment': 'comment',
        'role_action': 'role_action',
        'role_items': 'role_items',
        'role_name': 'role_name',
        'role_users': 'role_users'
    }

    def __init__(self, comment=None, role_action=None, role_items=None, role_name=None, role_users=None):  # noqa: E501
        """GetRoleReplyObj - a model defined in Swagger"""  # noqa: E501

        self._comment = None
        self._role_action = None
        self._role_items = None
        self._role_name = None
        self._role_users = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if role_action is not None:
            self.role_action = role_action
        if role_items is not None:
            self.role_items = role_items
        if role_name is not None:
            self.role_name = role_name
        if role_users is not None:
            self.role_users = role_users

    @property
    def comment(self):
        """Gets the comment of this GetRoleReplyObj.  # noqa: E501


        :return: The comment of this GetRoleReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this GetRoleReplyObj.


        :param comment: The comment of this GetRoleReplyObj.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def role_action(self):
        """Gets the role_action of this GetRoleReplyObj.  # noqa: E501


        :return: The role_action of this GetRoleReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._role_action

    @role_action.setter
    def role_action(self, role_action):
        """Sets the role_action of this GetRoleReplyObj.


        :param role_action: The role_action of this GetRoleReplyObj.  # noqa: E501
        :type: str
        """

        self._role_action = role_action

    @property
    def role_items(self):
        """Gets the role_items of this GetRoleReplyObj.  # noqa: E501


        :return: The role_items of this GetRoleReplyObj.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_items

    @role_items.setter
    def role_items(self, role_items):
        """Sets the role_items of this GetRoleReplyObj.


        :param role_items: The role_items of this GetRoleReplyObj.  # noqa: E501
        :type: list[str]
        """

        self._role_items = role_items

    @property
    def role_name(self):
        """Gets the role_name of this GetRoleReplyObj.  # noqa: E501


        :return: The role_name of this GetRoleReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this GetRoleReplyObj.


        :param role_name: The role_name of this GetRoleReplyObj.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def role_users(self):
        """Gets the role_users of this GetRoleReplyObj.  # noqa: E501


        :return: The role_users of this GetRoleReplyObj.  # noqa: E501
        :rtype: list[str]
        """
        return self._role_users

    @role_users.setter
    def role_users(self, role_users):
        """Sets the role_users of this GetRoleReplyObj.


        :param role_users: The role_users of this GetRoleReplyObj.  # noqa: E501
        :type: list[str]
        """

        self._role_users = role_users

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetRoleReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.dynamic_secret_message_queue_info import DynamicSecretMessageQueueInfo  # noqa: F401,E501


class DynamicSecretMQAccessReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'mq_info': 'DynamicSecretMessageQueueInfo',
        'receive_messages_signed_request': 'str'
    }

    attribute_map = {
        'mq_info': 'mq_info',
        'receive_messages_signed_request': 'receive_messages_signed_request'
    }

    def __init__(self, mq_info=None, receive_messages_signed_request=None):  # noqa: E501
        """DynamicSecretMQAccessReplyObj - a model defined in Swagger"""  # noqa: E501

        self._mq_info = None
        self._receive_messages_signed_request = None
        self.discriminator = None

        if mq_info is not None:
            self.mq_info = mq_info
        if receive_messages_signed_request is not None:
            self.receive_messages_signed_request = receive_messages_signed_request

    @property
    def mq_info(self):
        """Gets the mq_info of this DynamicSecretMQAccessReplyObj.  # noqa: E501


        :return: The mq_info of this DynamicSecretMQAccessReplyObj.  # noqa: E501
        :rtype: DynamicSecretMessageQueueInfo
        """
        return self._mq_info

    @mq_info.setter
    def mq_info(self, mq_info):
        """Sets the mq_info of this DynamicSecretMQAccessReplyObj.


        :param mq_info: The mq_info of this DynamicSecretMQAccessReplyObj.  # noqa: E501
        :type: DynamicSecretMessageQueueInfo
        """

        self._mq_info = mq_info

    @property
    def receive_messages_signed_request(self):
        """Gets the receive_messages_signed_request of this DynamicSecretMQAccessReplyObj.  # noqa: E501

        A signed request to receive messages from the Message Queue  # noqa: E501

        :return: The receive_messages_signed_request of this DynamicSecretMQAccessReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._receive_messages_signed_request

    @receive_messages_signed_request.setter
    def receive_messages_signed_request(self, receive_messages_signed_request):
        """Sets the receive_messages_signed_request of this DynamicSecretMQAccessReplyObj.

        A signed request to receive messages from the Message Queue  # noqa: E501

        :param receive_messages_signed_request: The receive_messages_signed_request of this DynamicSecretMQAccessReplyObj.  # noqa: E501
        :type: str
        """

        self._receive_messages_signed_request = receive_messages_signed_request

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DynamicSecretMQAccessReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DerivedFragmentReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'derivation_data': 'str',
        'derived_fragment': 'str'
    }

    attribute_map = {
        'derivation_data': 'derivation_data',
        'derived_fragment': 'derived_fragment'
    }

    def __init__(self, derivation_data=None, derived_fragment=None):  # noqa: E501
        """DerivedFragmentReplyObj - a model defined in Swagger"""  # noqa: E501

        self._derivation_data = None
        self._derived_fragment = None
        self.discriminator = None

        if derivation_data is not None:
            self.derivation_data = derivation_data
        if derived_fragment is not None:
            self.derived_fragment = derived_fragment

    @property
    def derivation_data(self):
        """Gets the derivation_data of this DerivedFragmentReplyObj.  # noqa: E501

        The derivation data that was used for the fragment derivation operation. Relevant for double derivation where the returned derivation data are different from the derivation seed that was received by the client  # noqa: E501

        :return: The derivation_data of this DerivedFragmentReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._derivation_data

    @derivation_data.setter
    def derivation_data(self, derivation_data):
        """Sets the derivation_data of this DerivedFragmentReplyObj.

        The derivation data that was used for the fragment derivation operation. Relevant for double derivation where the returned derivation data are different from the derivation seed that was received by the client  # noqa: E501

        :param derivation_data: The derivation_data of this DerivedFragmentReplyObj.  # noqa: E501
        :type: str
        """

        self._derivation_data = derivation_data

    @property
    def derived_fragment(self):
        """Gets the derived_fragment of this DerivedFragmentReplyObj.  # noqa: E501

        The derived fragment value  # noqa: E501

        :return: The derived_fragment of this DerivedFragmentReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._derived_fragment

    @derived_fragment.setter
    def derived_fragment(self, derived_fragment):
        """Sets the derived_fragment of this DerivedFragmentReplyObj.

        The derived fragment value  # noqa: E501

        :param derived_fragment: The derived_fragment of this DerivedFragmentReplyObj.  # noqa: E501
        :type: str
        """

        self._derived_fragment = derived_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DerivedFragmentReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import akeyless_uam_api
from akeyless_uam_api.api.default_api import DefaultApi  # noqa: E501
from akeyless_uam_api.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = akeyless_uam_api.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_account(self):
        """Test case for create_account

        Create new account.  # noqa: E501
        """
        pass

    def test_create_item(self):
        """Test case for create_item

        Add a new item to the account.  # noqa: E501
        """
        pass

    def test_create_role(self):
        """Test case for create_role

        Add a new role to the account.  # noqa: E501
        """
        pass

    def test_create_role_item_assoc(self):
        """Test case for create_role_item_assoc

        Add an association between a role and an item.  # noqa: E501
        """
        pass

    def test_create_role_user_assoc(self):
        """Test case for create_role_user_assoc

        Add an association between a role and a user.  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Add a new user to the account.  # noqa: E501
        """
        pass

    def test_delete_item(self):
        """Test case for delete_item

        Deleting an existing item from the account.  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Deleting an existing role from the account.  # noqa: E501
        """
        pass

    def test_delete_role_item_assoc(self):
        """Test case for delete_role_item_assoc

        Deleting an association between a role and an item.  # noqa: E501
        """
        pass

    def test_delete_role_user_assoc(self):
        """Test case for delete_role_user_assoc

        Deleting an association between a role and an user.  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Deleting an existing user from the account.  # noqa: E501
        """
        pass

    def test_get_account_details(self):
        """Test case for get_account_details

        Get account details.  # noqa: E501
        """
        pass

    def test_get_account_roles(self):
        """Test case for get_account_roles

        Get All the existing roles in the account.  # noqa: E501
        """
        pass

    def test_get_account_users(self):
        """Test case for get_account_users

        Get All the existing users in the account.  # noqa: E501
        """
        pass

    def test_get_dynamic_secret_mq_access(self):
        """Test case for get_dynamic_secret_mq_access

        Get a signed request to receive messages from a Message Queue of a Dynamic Secret.  # noqa: E501
        """
        pass

    def test_get_item(self):
        """Test case for get_item

        Get item details.  # noqa: E501
        """
        pass

    def test_get_item_derivation_creds(self):
        """Test case for get_item_derivation_creds

        Get temporary access credentials to KFM instances for item's fragments derivation.  # noqa: E501
        """
        pass

    def test_get_role(self):
        """Test case for get_role

        Get role details.  # noqa: E501
        """
        pass

    def test_get_rsa_key_decrypt_creds(self):
        """Test case for get_rsa_key_decrypt_creds

        Get temporary access credentials to KFM instances for RSA key fragments decryption.  # noqa: E501
        """
        pass

    def test_get_secret_access_creds(self):
        """Test case for get_secret_access_creds

        """
        pass

    def test_get_status(self):
        """Test case for get_status

        """
        pass

    def test_get_upload_rsa_key_creds(self):
        """Test case for get_upload_rsa_key_creds

        Get temporary access credentials to upload RSA private key fragments into KFMs instances.  # noqa: E501
        """
        pass

    def test_get_upload_secret_creds(self):
        """Test case for get_upload_secret_creds

        Get temporary access credentials to KFM instances to produce the derived protection key of the secret.  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get user details.  # noqa: E501
        """
        pass

    def test_get_user_items(self):
        """Test case for get_user_items

        Get All the items associated with the user.  # noqa: E501
        """
        pass

    def test_prepare_dynamic_secret_value(self):
        """Test case for prepare_dynamic_secret_value

        Get a signed request to receive messages from a Message Queue of a Dynamic Secret.  # noqa: E501
        """
        pass

    def test_update_item(self):
        """Test case for update_item

        Updating an existing item in the account  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Updating an existing role in the account  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updating an existing user in the account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetItemReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'certificates': 'str',
        'item_name': 'str',
        'item_roles': 'list[str]',
        'item_size': 'int',
        'item_type': 'str',
        'last_version': 'int',
        'public_value': 'str',
        'user_metadata': 'str',
        'with_customer_fragment': 'bool'
    }

    attribute_map = {
        'certificates': 'certificates',
        'item_name': 'item_name',
        'item_roles': 'item_roles',
        'item_size': 'item_size',
        'item_type': 'item_type',
        'last_version': 'last_version',
        'public_value': 'public_value',
        'user_metadata': 'user_metadata',
        'with_customer_fragment': 'with_customer_fragment'
    }

    def __init__(self, certificates=None, item_name=None, item_roles=None, item_size=None, item_type=None, last_version=None, public_value=None, user_metadata=None, with_customer_fragment=None):  # noqa: E501
        """GetItemReplyObj - a model defined in Swagger"""  # noqa: E501

        self._certificates = None
        self._item_name = None
        self._item_roles = None
        self._item_size = None
        self._item_type = None
        self._last_version = None
        self._public_value = None
        self._user_metadata = None
        self._with_customer_fragment = None
        self.discriminator = None

        if certificates is not None:
            self.certificates = certificates
        if item_name is not None:
            self.item_name = item_name
        if item_roles is not None:
            self.item_roles = item_roles
        if item_size is not None:
            self.item_size = item_size
        if item_type is not None:
            self.item_type = item_type
        if last_version is not None:
            self.last_version = last_version
        if public_value is not None:
            self.public_value = public_value
        if user_metadata is not None:
            self.user_metadata = user_metadata
        if with_customer_fragment is not None:
            self.with_customer_fragment = with_customer_fragment

    @property
    def certificates(self):
        """Gets the certificates of this GetItemReplyObj.  # noqa: E501


        :return: The certificates of this GetItemReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._certificates

    @certificates.setter
    def certificates(self, certificates):
        """Sets the certificates of this GetItemReplyObj.


        :param certificates: The certificates of this GetItemReplyObj.  # noqa: E501
        :type: str
        """

        self._certificates = certificates

    @property
    def item_name(self):
        """Gets the item_name of this GetItemReplyObj.  # noqa: E501


        :return: The item_name of this GetItemReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this GetItemReplyObj.


        :param item_name: The item_name of this GetItemReplyObj.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def item_roles(self):
        """Gets the item_roles of this GetItemReplyObj.  # noqa: E501


        :return: The item_roles of this GetItemReplyObj.  # noqa: E501
        :rtype: list[str]
        """
        return self._item_roles

    @item_roles.setter
    def item_roles(self, item_roles):
        """Sets the item_roles of this GetItemReplyObj.


        :param item_roles: The item_roles of this GetItemReplyObj.  # noqa: E501
        :type: list[str]
        """

        self._item_roles = item_roles

    @property
    def item_size(self):
        """Gets the item_size of this GetItemReplyObj.  # noqa: E501


        :return: The item_size of this GetItemReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._item_size

    @item_size.setter
    def item_size(self, item_size):
        """Sets the item_size of this GetItemReplyObj.


        :param item_size: The item_size of this GetItemReplyObj.  # noqa: E501
        :type: int
        """

        self._item_size = item_size

    @property
    def item_type(self):
        """Gets the item_type of this GetItemReplyObj.  # noqa: E501


        :return: The item_type of this GetItemReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._item_type

    @item_type.setter
    def item_type(self, item_type):
        """Sets the item_type of this GetItemReplyObj.


        :param item_type: The item_type of this GetItemReplyObj.  # noqa: E501
        :type: str
        """

        self._item_type = item_type

    @property
    def last_version(self):
        """Gets the last_version of this GetItemReplyObj.  # noqa: E501


        :return: The last_version of this GetItemReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._last_version

    @last_version.setter
    def last_version(self, last_version):
        """Sets the last_version of this GetItemReplyObj.


        :param last_version: The last_version of this GetItemReplyObj.  # noqa: E501
        :type: int
        """

        self._last_version = last_version

    @property
    def public_value(self):
        """Gets the public_value of this GetItemReplyObj.  # noqa: E501


        :return: The public_value of this GetItemReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._public_value

    @public_value.setter
    def public_value(self, public_value):
        """Sets the public_value of this GetItemReplyObj.


        :param public_value: The public_value of this GetItemReplyObj.  # noqa: E501
        :type: str
        """

        self._public_value = public_value

    @property
    def user_metadata(self):
        """Gets the user_metadata of this GetItemReplyObj.  # noqa: E501


        :return: The user_metadata of this GetItemReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata):
        """Sets the user_metadata of this GetItemReplyObj.


        :param user_metadata: The user_metadata of this GetItemReplyObj.  # noqa: E501
        :type: str
        """

        self._user_metadata = user_metadata

    @property
    def with_customer_fragment(self):
        """Gets the with_customer_fragment of this GetItemReplyObj.  # noqa: E501


        :return: The with_customer_fragment of this GetItemReplyObj.  # noqa: E501
        :rtype: bool
        """
        return self._with_customer_fragment

    @with_customer_fragment.setter
    def with_customer_fragment(self, with_customer_fragment):
        """Sets the with_customer_fragment of this GetItemReplyObj.


        :param with_customer_fragment: The with_customer_fragment of this GetItemReplyObj.  # noqa: E501
        :type: bool
        """

        self._with_customer_fragment = with_customer_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetItemReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from akeyless_uam_api.models.user_access_policy_info import UserAccessPolicyInfo  # noqa: F401,E501


class GetUserReplyObj(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_info': 'UserAccessPolicyInfo',
        'account_id': 'str',
        'user_name': 'str',
        'user_policy_id': 'str',
        'user_roles': 'list[str]'
    }

    attribute_map = {
        'access_info': 'access_info',
        'account_id': 'account_id',
        'user_name': 'user_name',
        'user_policy_id': 'user_policy_id',
        'user_roles': 'user_roles'
    }

    def __init__(self, access_info=None, account_id=None, user_name=None, user_policy_id=None, user_roles=None):  # noqa: E501
        """GetUserReplyObj - a model defined in Swagger"""  # noqa: E501

        self._access_info = None
        self._account_id = None
        self._user_name = None
        self._user_policy_id = None
        self._user_roles = None
        self.discriminator = None

        if access_info is not None:
            self.access_info = access_info
        if account_id is not None:
            self.account_id = account_id
        if user_name is not None:
            self.user_name = user_name
        if user_policy_id is not None:
            self.user_policy_id = user_policy_id
        if user_roles is not None:
            self.user_roles = user_roles

    @property
    def access_info(self):
        """Gets the access_info of this GetUserReplyObj.  # noqa: E501


        :return: The access_info of this GetUserReplyObj.  # noqa: E501
        :rtype: UserAccessPolicyInfo
        """
        return self._access_info

    @access_info.setter
    def access_info(self, access_info):
        """Sets the access_info of this GetUserReplyObj.


        :param access_info: The access_info of this GetUserReplyObj.  # noqa: E501
        :type: UserAccessPolicyInfo
        """

        self._access_info = access_info

    @property
    def account_id(self):
        """Gets the account_id of this GetUserReplyObj.  # noqa: E501


        :return: The account_id of this GetUserReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this GetUserReplyObj.


        :param account_id: The account_id of this GetUserReplyObj.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def user_name(self):
        """Gets the user_name of this GetUserReplyObj.  # noqa: E501


        :return: The user_name of this GetUserReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this GetUserReplyObj.


        :param user_name: The user_name of this GetUserReplyObj.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def user_policy_id(self):
        """Gets the user_policy_id of this GetUserReplyObj.  # noqa: E501


        :return: The user_policy_id of this GetUserReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._user_policy_id

    @user_policy_id.setter
    def user_policy_id(self, user_policy_id):
        """Sets the user_policy_id of this GetUserReplyObj.


        :param user_policy_id: The user_policy_id of this GetUserReplyObj.  # noqa: E501
        :type: str
        """

        self._user_policy_id = user_policy_id

    @property
    def user_roles(self):
        """Gets the user_roles of this GetUserReplyObj.  # noqa: E501


        :return: The user_roles of this GetUserReplyObj.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_roles

    @user_roles.setter
    def user_roles(self, user_roles):
        """Sets the user_roles of this GetUserReplyObj.


        :param user_roles: The user_roles of this GetUserReplyObj.  # noqa: E501
        :type: list[str]
        """

        self._user_roles = user_roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetUserReplyObj):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from akeyless_uam_api.api.default_api import DefaultApi

# import ApiClient
from akeyless_uam_api.api_client import ApiClient
from akeyless_uam_api.configuration import Configuration
# import models into sdk package
from akeyless_uam_api.models.algorithm import Algorithm
from akeyless_uam_api.models.auth_status_reply_obj import AuthStatusReplyObj
from akeyless_uam_api.models.azure_ad_access_role import AzureADAccessRole
from akeyless_uam_api.models.create_account_creds_params import CreateAccountCredsParams
from akeyless_uam_api.models.create_account_reply_obj import CreateAccountReplyObj
from akeyless_uam_api.models.create_policy_reply_obj import CreatePolicyReplyObj
from akeyless_uam_api.models.create_user_reply_obj import CreateUserReplyObj
from akeyless_uam_api.models.credentials_reply_obj import CredentialsReplyObj
from akeyless_uam_api.models.derivation_creds_reply_obj import DerivationCredsReplyObj
from akeyless_uam_api.models.derived_fragment_reply_obj import DerivedFragmentReplyObj
from akeyless_uam_api.models.dynamic_secret_mq_access_reply_obj import DynamicSecretMQAccessReplyObj
from akeyless_uam_api.models.dynamic_secret_message_queue_info import DynamicSecretMessageQueueInfo
from akeyless_uam_api.models.error_reply_obj import ErrorReplyObj
from akeyless_uam_api.models.fragment_type import FragmentType
from akeyless_uam_api.models.get_account_details_reply_obj import GetAccountDetailsReplyObj
from akeyless_uam_api.models.get_account_roles_reply_obj import GetAccountRolesReplyObj
from akeyless_uam_api.models.get_account_users_reply_obj import GetAccountUsersReplyObj
from akeyless_uam_api.models.get_fragment_details_reply_obj import GetFragmentDetailsReplyObj
from akeyless_uam_api.models.get_item_reply_obj import GetItemReplyObj
from akeyless_uam_api.models.get_policies_reply_obj import GetPoliciesReplyObj
from akeyless_uam_api.models.get_policy_reply_obj import GetPolicyReplyObj
from akeyless_uam_api.models.get_role_reply_obj import GetRoleReplyObj
from akeyless_uam_api.models.get_user_items_reply_obj import GetUserItemsReplyObj
from akeyless_uam_api.models.get_user_reply_obj import GetUserReplyObj
from akeyless_uam_api.models.kfm_status_reply_obj import KFMStatusReplyObj
from akeyless_uam_api.models.o_auth2_access_role import OAuth2AccessRole
from akeyless_uam_api.models.o_auth2_custom_claim import OAuth2CustomClaim
from akeyless_uam_api.models.policy_params import PolicyParams
from akeyless_uam_api.models.policy_rules import PolicyRules
from akeyless_uam_api.models.policy_rules_type import PolicyRulesType
from akeyless_uam_api.models.policy_type import PolicyType
from akeyless_uam_api.models.prepare_dynamic_secret_value_reply_obj import PrepareDynamicSecretValueReplyObj
from akeyless_uam_api.models.public_signing_key_reply_obj import PublicSigningKeyReplyObj
from akeyless_uam_api.models.rsa_decrypt_creds_reply_obj import RSADecryptCredsReplyObj
from akeyless_uam_api.models.rsa_fragment_decrypt_reply_obj import RSAFragmentDecryptReplyObj
from akeyless_uam_api.models.secret_access_creds_reply_obj import SecretAccessCredsReplyObj
from akeyless_uam_api.models.set_uam_policy_creds_params import SetUAMPolicyCredsParams
from akeyless_uam_api.models.system_user_credentials_reply_obj import SystemUserCredentialsReplyObj
from akeyless_uam_api.models.time_reply_obj import TimeReplyObj
from akeyless_uam_api.models.uam_status_reply_obj import UAMStatusReplyObj
from akeyless_uam_api.models.update_policy_mode import UpdatePolicyMode
from akeyless_uam_api.models.upload_rsa_fragment_reply_obj import UploadRSAFragmentReplyObj
from akeyless_uam_api.models.upload_rsa_key_creds_reply_obj import UploadRSAKeyCredsReplyObj
from akeyless_uam_api.models.user_access_policy_info import UserAccessPolicyInfo
from akeyless_uam_api.models.validate_client_creds_reply_obj import ValidateClientCredsReplyObj



# coding: utf-8

"""
    UAM - Application API

    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key's metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501

    OpenAPI spec version: 1.0.6
    Contact: refael@akeyless-security.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "akeyless-uam-api"
VERSION = "0.0.9"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="UAM - Application API",
    author_email="refael@akeyless-security.com",
    url="https://www.akeyless-security.com/",
    keywords=["Swagger", "UAM - Application API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    UAM manages client accounts and allows each client to define users, roles and master keys. The core operations of UAM are as follows: Creating new accounts. For each account: Creating new master keys. Adding new users Adding new roles Attaching roles to users. Attaching roles to keys. Returning the key&#39;s metadata together with temporary access credentials in order to access the key fragments.  # noqa: E501
    """
)
